<ul class="toctree nav nav-list">

  {% if project == 'OKCDocs' %}
  <li class="navleft-item">
    <a class="project" href="{{ pathto(master_doc) }}">OKC</a>
    {{ toctree(maxdepth=2|toint, collapse=True, includehidden=theme_globaltoc_includehidden|tobool) }}
  </li>
  {% else %}
  <li class="navleft-item" style="display: none">
      <a  class="project" href="https://okc-docs.readthedocs.io/en/latest/">OKC</a>
  </li>
  {% endif %}

  {% if project == 'OIPs' %}
  <li class="navleft-item">
    <a class="project" href="{{ pathto(master_doc) }}">OIPs</a>
    {{ toctree(maxdepth=1, collapse=False, includehidden=theme_globaltoc_includehidden|tobool) }}
  </li>
  {% else %}
  <li class="navleft-item" style="display: none">
    <a  class="project" href="https://oips.readthedocs.io/en/latest/">OIPs</a>
  </li>
  {% endif %}

  <!--maxdepth=1|toint
  <li class="navleft-item border-top"><a href="https://github.com/crate/crate-sample-apps">Sample Applications</a></li>
  <li class="navleft-item"><a href="/support/">Support</a></li>
  -->
</ul>
