{#
    basic/community.html
    ~~~~~~~~~~~~~~~~~

    Template for the search page.

    :copyright: Copyright 2007-2013 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
{%- extends "layout.html" %}
{% set title = _('Community') %}

{% block extra_head %}
<link rel="stylesheet" href="{{ pathto('_static/css/community.css', 1) }}?ver=1.2" type="text/css" />
<script type="text/javascript" src="{{ pathto('_static/js/community.js, 1) }}?ver=1.2"></script>
{% endblock %}

{% block body %}

<div class="container">
  <h1 id="community-title">{{ _('Community') }}</h1>
  <noscript>
    <div id="fallback" class="admonition warning">
    <p>
      {% trans %}Please activate JavaScript to enable the community
      functionality.{% endtrans %}
    </p>
    </div>
  </noscript>

  <div>Discuss OKC with the community with one of the following channels.</div>

  <div class="social-communication">
    <div class="item">
      <div class="item-icon">
        <a class="icon-telegram-developer" href="https://t.me/okchaintech" target="_blank">
          <svg class="icon" aria-hidden="true">
            <use xlink:href="#iconicon_telegram"></use>
          </svg>
        </a>
      </div>
      <div class="item-desc">
        <div>Telegram Developer</div>
        <div>Talk to OKC developers</div>
      </div>
    </div>

    <div class="item">
      <div class="item-icon">
        <a class="icon-telegram-validator" href="https://t.me/joinchat/HuUCNktBLftzEY1fZPStkw" target="_blank">
          <svg class="icon" aria-hidden="true">
            <use xlink:href="#iconicon_telegram"></use>
          </svg>
        </a>
      </div>
      <div class="item-desc">
        <div>Telegram Validator</div>
        <div>Talk to OKC validators</div>
      </div>
    </div>

    <div class="item">
      <div class="item-icon">
        <a class="icon-twitter-community" href="https://twitter.com/OKChain2" target="_blank">
          <svg class="icon" aria-hidden="true">
            <use xlink:href="#iconicon_twitter"></use>
          </svg>
        </a>
      </div>
      <div class="item-desc">
        <div>Twitter</div>
        <div>@OKC</div>
      </div>
    </div>

    <div class="item">
      <div class="item-icon">
        <a class="icon-email-community" href="mailto:okchain@okg.com">
          <svg class="icon" aria-hidden="true">
            <use xlink:href="#iconicon_email"></use>
          </svg>
        </a>
      </div>
      <div class="item-desc">
        <div>E-mail</div>
        <div>okchain@okg.com</div>
      </div>
    </div>
  </div>

  <div class="dex-operator">
    <div class="dex-operator-logo"></div>
    <div class="dex-operator-desc">
      <div class="dex-operator-title">To be DEX Operator</div>
      <div class="dex-operator-description">in hours</div>
      <a href="https://okc-docs.readthedocs.io/en/latest/dex-trades/dex-trades-overview.html">GET STARTED</a>
    </div>
  </div>

  <div class="validator">
    <div class="validator-logo"></div>
    <div class="validator-desc">
      <div class="validator-title">To be Validator</div>
      <div class="validator-description">in hours</div>
      <a href="https://okc-docs.readthedocs.io/en/latest/validators/validators-overview.html">GET STARTED</a>
    </div>
  </div>

</div>

{% endblock %}
