<input type="checkbox" id="mobile-nav-new">

<header class="header-nav">
  <div class="container">
    <div class="navbar w-nav" data-animation="default" data-collapse="small" data-contain="1" data-duration="400">
      <a class="brand w-nav-brand" href="https://okc-docs.readthedocs.io/en/latest/">
        <img src="{{ pathto('_static', 1) }}/images/logo-okc.png" width="70" height="38">
      </a>
      <nav class="w-nav-menu main-nav" role="navigation">
        <div class="dropdownBackground">
          <span class="arrow"></span>
        </div>
        <ul id="menu-top-navigation" class="menu">
          <li class="navlink w-nav-link menu-item">
            <a href="https://kips.readthedocs.io/en/latest/">KIPs</a>
            <!--  li class = menu-item-has-children
            <ul class="sub-menu">
              <li class="menu-item"><a href="https://crate.io/products/cratedb/">CrateDB</a></li>
              <li class="menu-item"><a href="https://crate.io/products/cratedb-cloud-on-azure/">CrateDB Cloud on Azure</a></li>
              <li class="menu-item"><a href="https://crate.io/products/cratedb-cloud/">CrateDB Cloud</a></li>
              <li class="menu-item"><a href="https://crate.io/products/crate-iot-data-platform/">Crate IoT Data Platform</a></li>
            </ul>-->
          </li>
          <li class="navlink w-nav-link menu-item ">
            <a href="https://okc-docs.readthedocs.io/en/latest/">Documentation</a>
            <!--  li class = menu-item-has-children
            <ul class="sub-menu">
              <li class="menu-item"><a href="https://crate.io/customers/">Customers</a></li>
              <li class="menu-item"><a href="https://crate.io/use-cases/iot-sensor-data/">IoT &amp; Sensor Data</a></li>
              <li class="menu-item"><a href="https://crate.io/use-cases/time-series/">Time Series</a></li>
              <li class="menu-item"><a href="https://crate.io/use-cases/geospatial-analytics/">Geospatial Analytics</a></li>
              <li class="menu-item"><a href="https://crate.io/use-cases/cyber-security/">Cybersecurity</a></li>
            </ul>-->
          </li>
          <li class="navlink w-nav-link menu-item"><a href="{{ pathto('community') }}">Community</a></li>
          <li class="navlink w-nav-link menu-item ">
            <a href="https://www.okx.com/academy/en/category/okchain-en/ecology-construction-en" target="_blank">Blog</a>
            <!--  li class = menu-item-has-children
            <ul class="sub-menu">
              <li class="menu-item"><a href="https://crate.io/docs/">Documentation</a></li>
              <li class="menu-item"><a href="https://crate.io/resources/">Resource Library</a></li>
              <li class="menu-item"><a href="https://crate.io/community/">Community</a></li>
              <li class="menu-item"><a href="https://crate.io/partner/">Partners</a></li>
            </ul>-->
          </li>
          <li class="btn-link w-nav-link menu-item">
            {%- if project == 'OKChainDocs' %}
            <a href="https://github.com/okex/okexchain-docs" target="_blank">Github</a>
            {%- endif %}

            {%- if project == 'OIPs' %}
            <a href="https://github.com/okex/KIPs" target="_blank">Github</a>
            {%- endif %}
          </li>
        </ul>
      </nav>

      <label for="mobile-nav-new" class="fa fa-bars mobile-nav-button"></label>
    </div>
  </div>
</header>
